==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/Manager.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * Manager
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class Manager extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<Manager> {

    /** Manager attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** uniqueId column */
        public static final String UNIQUEID ="uniqueId";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("uniqueId");

            return list;
        }
    }

    /** Field attributes */
    public static ManagerFieldAttributes FieldAttributes=new ManagerFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public ManagerFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * areas relation.
         *
         * @return the areas bean relations attributes.
         */
        public Area.Relations areas()
        {
            Area c = new Area();
            return c.new Relations(this.buildPath("areas"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the UNIQUEID path.
         *
         * @return the path
         */
        public String UNIQUEID()
        {
            return buildPath(Fields.UNIQUEID);
        }
    }

    /** The dummy obj. */
    private static Manager dummyObj=new Manager();

    /**
     * Get Manager Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<Manager> getDataSet()
    {
        return new HibernateDataSet<Manager>(Manager.class, HibernateUtil.getSessionFactory("DIFRepository"),
            Manager.getPKFieldListAsString(), Manager.FieldAttributes);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<Manager> getDataSetInstance()
    {
        return new Manager().getDataSet();
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("uniqueId".equalsIgnoreCase(attributeName))
            return uniqueId;
        if("areas".equalsIgnoreCase(attributeName))
            return areas;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("uniqueId".equalsIgnoreCase(attributeName))
            uniqueId =(String)attributeValue;
        if("areas".equalsIgnoreCase(attributeName))
            areas =(Set<Area>)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** uniqueId private attribute */
    private String uniqueId;

    /** areas private attribute */
    private Set<Area> areas = new HashSet<Area>(0);

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public Manager() {
    }

	/** 
	 * minimal constructor
	 *
     * @param uniqueId the uniqueId
    }
	 */
    public Manager(String uniqueId) {
        this.uniqueId = uniqueId;
    }

    /**
     * full constructor
	 *
     * @param uniqueId the uniqueId
     * @param areas the areas
     */
    public Manager(String uniqueId, Set<Area> areas) {
        this.uniqueId = uniqueId;
        this.areas = areas;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return Manager modified instance
     */
    public Manager setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * uniqueId getter method
     *
     * @return uniqueId method
     */
    public String getUniqueId() {
        return this.uniqueId;
    }
    
    /**       
     * uniqueId setter method
     *
     * @param uniqueId the uniqueId
     *
     * @return Manager modified instance
     */
    public Manager setUniqueId(String uniqueId) {
        this.uniqueId = uniqueId;
        
        return this;
    }
    /**       
     * areas getter method
     *
     * @return areas method
     */
    public Set<Area> getAreas() {
        return this.areas;
    }
    
    /**       
     * areas setter method
     *
     * @param areas the areas
     *
     * @return Manager modified instance
     */
    public Manager setAreas(Set<Area> areas) {
        this.areas = areas;
        
        return this;
    }

    /**
     * Creates a String representation of the Manager object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("uniqueId").append("='").append(getUniqueId()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the Manager object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(Manager other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("uniqueId".equalsIgnoreCase(attributeName))
        	this.uniqueId = attributeValue;

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static Manager getProxy(Session session, Long id)
    {
        return(Manager)session.load(Manager.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static Manager getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        Manager result = (Manager)session.load(Manager.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static Manager getInstance(Session session, Long id)
    {
        return(Manager)session.get(Manager.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static Manager getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        Manager result = (Manager)session.get(Manager.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/Manager.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * Manager
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class Manager extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<Manager> {

    /**
    * Constant with the session factory ID
    */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /** Manager attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** uniqueId column */
        public static final String UNIQUEID ="uniqueId";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("uniqueId");

            return list;
        }
    }

    /** Field attributes */
    public static ManagerFieldAttributes FieldAttributes=new ManagerFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public ManagerFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * areas relation.
         *
         * @return the areas bean relations attributes.
         */
        public Area.Relations areas()
        {
            Area c = new Area();
            return c.new Relations(this.buildPath("areas"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the UNIQUEID path.
         *
         * @return the path
         */
        public String UNIQUEID()
        {
            return buildPath(Fields.UNIQUEID);
        }
    }

    /** The dummy obj. */
    private static Manager dummyObj=new Manager();

    /**
     * Get Manager Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<Manager> getDataSet()
    {
        return getDataSetInstance();
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<Manager> getDataSetInstance()
    {
        return new HibernateDataSet<Manager>(Manager.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
            Manager.getPKFieldListAsString(), Manager.FieldAttributes);
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("uniqueId".equalsIgnoreCase(attributeName))
            return uniqueId;
        if("areas".equalsIgnoreCase(attributeName))
            return areas;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("uniqueId".equalsIgnoreCase(attributeName))
            uniqueId =(String)attributeValue;
        if("areas".equalsIgnoreCase(attributeName))
            areas =(Set<Area>)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** uniqueId private attribute */
    private String uniqueId;

    /** areas private attribute */
    private Set<Area> areas = new HashSet<Area>(0);

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * Gets description field.
     *
     * @return the description field
     */
    @Override
    public String getDescriptionField()
    {
        return FieldAttributes.getDescriptionField();
    }

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    @Override
    public List<String> getPKFields()
    {
        return getPKFieldList();
    }

    /**
     * Is composite PK.
     *
     * @return the boolean
     */
    @Override
    public boolean isCompositePK()
    {
        return this.getPKFieldList().size() > 1;
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {
        if (attributeName.contains("."))
        {
            return this.getAttributeAsStringParseBeanPath(attributeName);
        }
        else
        {
            Object value = getAttribute(attributeName);

            if (value == null)
                return "";
            else {
                return value.toString().trim();
            }
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public Manager() {
    }

	/** 
	 * minimal constructor
	 *
     * @param uniqueId the uniqueId
    }
	 */
    public Manager(String uniqueId) {
        this.uniqueId = uniqueId;
    }

    /**
     * full constructor
	 *
     * @param uniqueId the uniqueId
     * @param areas the areas
     */
    public Manager(String uniqueId, Set<Area> areas) {
        this.uniqueId = uniqueId;
        this.areas = areas;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return Manager modified instance
     */
    public Manager setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * uniqueId getter method
     *
     * @return uniqueId method
     */
    public String getUniqueId() {
        return this.uniqueId;
    }
    
    /**       
     * uniqueId setter method
     *
     * @param uniqueId the uniqueId
     *
     * @return Manager modified instance
     */
    public Manager setUniqueId(String uniqueId) {
        this.uniqueId = uniqueId;
        
        return this;
    }
    /**       
     * areas getter method
     *
     * @return areas method
     */
    public Set<Area> getAreas() {
        return this.areas;
    }
    
    /**       
     * areas setter method
     *
     * @param areas the areas
     *
     * @return Manager modified instance
     */
    public Manager setAreas(Set<Area> areas) {
        this.areas = areas;
        
        return this;
    }


    /**
     * Creates a String representation of the Manager object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("uniqueId").append("='").append(getUniqueId()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the Manager object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(Manager other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("uniqueId".equalsIgnoreCase(attributeName))
        	this.uniqueId = attributeValue;

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static Manager getProxy(Session session, Long id)
    {
        return(Manager)session.load(Manager.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static Manager getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        Manager result = (Manager)session.load(Manager.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static Manager getInstanceForSession(Session session, Long id)
    {
        return(Manager)session.get(Manager.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static Manager getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        Manager result = (Manager)session.get(Manager.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}
